# PHP & API versions for cross-checking purposes
%define apiver 20190902
%define zendver 20190902

# The version of the OCI8 PECL extension being installed, ie. taken
# from the filename oci8-a.b.c.tgz
%define oci8peclver 2.2.0

# Versions of Instant Client RPM
%define instantclient_ver 21.3.0.0.0
%define instantclient_ver_short %{expand:%%(echo %{instantclient_ver} | sed 's/\.[0-9]*\.[0-9]*\.[0-9]*\.[0-9]*$//')}
%ifarch x86_64
%define instantclient_libpath /usr/lib/oracle/%{instantclient_ver_short}/client64/lib
%else
%define instantclient_libpath /usr/lib/oracle/%{instantclient_ver_short}/client/lib
%endif

# Install location of files
%define basefiledir %{_libdir}/oracle

# PHP OCI8 package release
%define phprelease 4

# PHP version
%define phpversion 7.4.6

# Oracle DB version
%define oracledbversion 21c


Summary: The PHP OCI8 Extension module for PHP applications using the Oracle database
Name: php-oci8
Group: Development/Languages
Version: %{oci8peclver}
Release: 1.0.1%{?dist}
License: The PHP License v3.01
URL: http://www.php.net/

Source0: http://pecl.php.net/get/oci8-%{oci8peclver}.tgz

BuildRoot: %{_tmppath}/%{name}-root

%description
The php-oci8 package contains a dynamic shared object for the
Apache Web server, CGI and command line PHP.  OCI8 is an extension for
Oracle Database access.  PHP is an HTML-embedded scripting language.
If you need Oracle support for PHP applications, you can install this
package and the php package.

%package %{oracledbversion}
Summary: The PHP OCI8 Extension module for PHP applications using the Oracle database
Group: Development/Languages

BuildRoot: %{_tmppath}/%{name}-root

Requires: php-common >= %{phpversion}
Requires: oracle-instantclient-basic >= %{instantclient_ver}
Requires: libaio >= 0.3.105
BuildRequires: oracle-instantclient-devel >= %{instantclient_ver}
BuildRequires: php-devel >= %{phpversion}
BuildRequires: fileutils, file >= 4.0, libtool >= 1.4.3, gcc-c++
Provides: php_database, php-oci, mod_php = %{phpversion}-%{phprelease}
AutoReqProv: No

%description %{oracledbversion}
The php-oci8 package contains a dynamic shared object for the
Apache Web server, CGI and command line PHP.  OCI8 is an extension for
Oracle Database access.  PHP is an HTML-embedded scripting language.
If you need Oracle support for PHP applications, you can install this
package and the php package.

%prep
rm -rf oci8-%{oci8peclver} oci8-%{oci8peclver}
tar -zxf %{_sourcedir}/oci8-%{oci8peclver}.tgz

# Safety check for API version change.
vapi=`phpize -v | sed -n '/PHP Api Version:/{s/.* //;p}'`
if test "x${vapi}" != "x%{apiver}"; then
   : Error: Upstream API version is now ${vapi}, expecting %{apiver}.
   : Update the apiver macro and rebuild.
   exit 1
fi

# Safety check for Zend API version change.
vzend=`phpize -v | sed -n '/Zend Module Api No:/{s/^[^0-9]*//;p;}'`
if test "x${vzend}" != "x%{zendver}"; then
   : Error: Upstream Zend module ABI version is now ${vzend}, expecting %{zendver}.
   : Update the zendver macro and rebuild.
   exit 1
fi

%build
pushd oci8-%{oci8peclver}
phpize

CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing -Wno-pointer-sign"
export CFLAGS

# Build the oci8 extension
%configure --with-oci8=shared,instantclient,%{instantclient_libpath}
if test $? != 0; then
   tail -500 config.log
   : configure failed
   exit 1
fi

make %{?_smp_mflags}

%install
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

pushd oci8-%{oci8peclver}
make install INSTALL_ROOT=$RPM_BUILD_ROOT

install -m 755 -d $RPM_BUILD_ROOT%{_sysconfdir}/php.d

# Generate stub .ini file
cat > $RPM_BUILD_ROOT/%{_sysconfdir}/php.d/oci8.ini <<EOF
; Enable OCI8 extension module
extension=oci8.so

[OCI8]

; Connection: Enables privileged connections using external
; credentials (OCI_SYSOPER, OCI_SYSDBA)
;oci8.privileged_connect = Off

; Connection: The maximum number of persistent OCI8 connections per
; process. Using -1 means no limit.
;oci8.max_persistent = -1

; Connection: The maximum number of seconds a process is allowed to
; maintain an idle persistent connection. Using -1 means idle
; persistent connections will be maintained forever.
;oci8.persistent_timeout = -1

; Connection: The number of seconds that must pass before issuing a
; ping during oci_pconnect() to check the connection validity. When
; set to 0, each oci_pconnect() will cause a ping. Using -1 disables
; pings completely.
;oci8.ping_interval = 60

; Connection: Set this to a user chosen connection class to be used
; for all pooled server requests with Oracle 12g Database Resident
; Connection Pooling (DRCP).  To use DRCP, this value should be set to
; the same string for all web servers running the same application,
; the database pool must be configured, and the connection string must
; specify to use a pooled server.
;oci8.connection_class =

; High Availability: Using On lets PHP receive Fast Application
; Notification (FAN) events generated when a database node fails. The
; database must also be configured to post FAN events.
;oci8.events = Off

; Tuning: This option enables statement caching, and specifies how
; many statements to cache. Using 0 disables statement caching.
;oci8.statement_cache_size = 20

; Tuning: Enables statement prefetching and sets the default number of
; rows that will be fetched automatically after statement execution.
;oci8.default_prefetch = 100

; Compatibility. Using On means oci_close() will not close
; oci_connect() and oci_new_connect() connections.
;oci8.old_oci_close_semantics = Off

EOF

%clean
[ "x${RPM_BUILD_ROOT}" != "x/" ] && rm -rf $RPM_BUILD_ROOT

%files %{oracledbversion}
%attr(755,root,root) %{_libdir}/php/modules/oci8.so
%config(noreplace) %attr(644,root,root) %{_sysconfdir}/php.d/oci8.ini

%changelog
* Mon Sep 27 2021 Lans Hung <lans.hung@oracle.com> 2.2.0-1.0.1
- Use PECL php-oci8 2.2.0
- Use Oracle Intant Client 21.3.0.0.0
- Build for php7 on OL8

